Given a time variable and optional covariates, generate predicted values from
a cosinor fit. Default prediction is the mean value, optionally can predict
at a given month
Usage
# S3 method for cglmm
predict(object, newdata, ...)
Value
Returns predicted values from the cosinor model.
Arguments
object
An object of class cglmm.
newdata
Optional new data.
...
other arguments passed to glmmTMB:::predict.glmmTMB.