Learn R Programming

GLMMcosinor (version 0.2.0)

summary.cglmm: Summarize a cosinor model Given a time variable and optional covariates, generate inference a cosinor fit. Gives estimates, confidence intervals, and tests for the raw parameters, and for the mean, amplitude, and acrophase parameters. If the model includes covariates, the function returns the estimates of the mean, amplitude, and acrophase for the group with covariates equal to 1 and equal to 0. This may not be the desired result for continuous covariates.

Description

Summarize a cosinor model Given a time variable and optional covariates, generate inference a cosinor fit. Gives estimates, confidence intervals, and tests for the raw parameters, and for the mean, amplitude, and acrophase parameters. If the model includes covariates, the function returns the estimates of the mean, amplitude, and acrophase for the group with covariates equal to 1 and equal to 0. This may not be the desired result for continuous covariates.

Usage

# S3 method for cglmm
summary(object, ci_level = 0.95, ...)

Value

Returns a summary of the cglmm model as a cglmmSummary object.

Arguments

object

An object of class cglmm

ci_level

The level for calculated confidence intervals. Defaults to 0.95.

...

Currently unused

Examples

Run this code


fit <- cglmm(vit_d ~ X + amp_acro(time,
  group = "X",
  n_components = 1,
  period = 12
), data = vitamind)
summary(fit)

Run the code above in your browser using DataLab